OM_START_URL = "https://front{}.omegle.com/start"
OM_DISCONNECT_URL = "https://front{}.omegle.com/disconnect"
OM_EVENTS_URL = "https://front{}.omegle.com/events"
OM_START_TYPING_URL = "https://front{}.omegle.com/typing"
OM_STOP_TYPING_URL = "https://front{}.omegle.com/stoppedtyping"
OM_SEND_URL = "https://front{}.omegle.com/send"



import random
import requests
import sys
import string
import threading
import json
import time
from pyomgclient.utils import config
from pyomgclient.utils.generators import *
from pyomgclient import __version__
class Client:
  def __init__ (self, lang = "en", on_start = None, on_error = None, on_disconnect = None, on_message = None, on_typing = None):
    self.lang = lang
    self.port = generate_port()
    self.version = __version__
    self.randid = generate_randid()
    self.session = requests.Session()
    self.clientId = False
    self.typing = False
    self.events = {}
    self.poll = threading.Thread (target=self.events_handler)

  def events_handler (self):
    while True:
      ev = json.loads(requests.post (config.OM_EVENTS_URL.format(str(self.port)), {"id": self.clientId}).text)
      if ev:
        for i in ev:
          if i[0] in self.events:
            func = self.events.get(i[0])
            if i[0] == "gotMessage":
              func(i[1])
            else:
              func()
          
    time.sleep (1)

  def send_message (self, msg, typ = False):
    url = config.OM_SEND_URL.format(str(self.port))
    payload = {
        "id": self.clientId,
        "msg": msg
    }
    if not typ:
      self.session.post (url, payload)
    else:
      self.start_typing ()
      time.sleep (1)
      self.stop_typing ()
      self.session.post (url, payload)

  def start_typing (self):
    url = config.OM_START_TYPING_URL.format(str(self.port))
    payload = {
        "id": self.clientId
    }
    if not self.typing:
      self.session.post(url, payload)
      self.typing = True
    else:
      return False

  def stop_typing (self):
    url = config.OM_STOP_TYPING_URL.format(str(self.port))
    payload = {
        "id": self.clientId
    }
    if self.typing:
      self.session.post (url, payload)
      self.typing = False
    else:
      return False

  def start (self):
    res = generate_client_id(port = self.port, randid = self.randid, session = self.session)
    if res["events"]:
      for i in res["events"]:
        if i[0] == "recaptchaRequired" and "recaptchaRequired" in self.events:
          self.events["recaptchaRequired"](i[1])
          
    else:
      self.clientId = res["clientID"]
      if self.events.get("start"):
        self.events.get("start")()

    if not self.poll.is_alive(): self.poll.start()


  
  def credentials (self):
    creds = {}
    creds["lang"] = self.lang
    creds["version"] = self.version
    creds["port"] = self.port
    creds["clientId"] = self.clientId
    creds["randid"] = self.randid
    return creds

  def set_on_message_cb (self, cb):
    self.events["gotMessage"] = cb

  def set_on_start_cb (self, cb):
    self.events["start"] = cb

  def set_on_typing_cb (self, cb):
    self.events["typing"] = cb

  def set_on_disconnect_cb (self, cb):
    self.events["strangerDisconnected"] = cb

  def set_on_recaptcha_cb (self, cb):
    self.events["recaptchaRequired"] = cb





from setuptools import setup, find_packages
import os

here = os.path.abspath(os.path.dirname(__file__))

with open(os.path.join(here, "README.md"), encoding="utf-8") as fh:
    long_description = "\n" + fh.read()

VERSION = "1.1.0"
setup(
    name="pyomgclient",
    version=VERSION,
    author="Team XProjects",
    description="a python omegle client",
    long_description_content_type="text/markdown",
    long_description=long_description,
    packages=find_packages(),
    install_requires=['requests', 'colorama'],
    keywords=['python', 'omegle', 'XProjects', 'TheXProjects', 'client', 'omegleclient', 'pyomgclient', 'omgclient', 'pythonomengleclient'],
    classifiers=[
        "Development Status :: 2 - Pre-Alpha",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
    ]
)



import random
from pyomgclient.utils import config
import string
import json

ports = ['30', '42', '48', '35', '37', '14', '17', '5', '11', '18', '26', '31', '20', '19', '38', '8', '16', '13', '1', '29', '47', '41', '39', '34', '44', '10', '45', '40', '3', '33', '46', '23', '43', '15', '9', '7', '6', '24', '22', '2', '32', '25', '28', '21', '12', '4', '27', '36']

def generate_port ():
  return ports[random.randint (1, len(ports))]

def generate_randid ():
  result = random.choices (string.ascii_uppercase, k=8)
  fres = ""
  for i in result:
    fres += i
  return str(random.randint(1,9))+str(fres)

def generate_client_id (port, randid, session, lang = "en"):

  payload = {
    "caps": "recaptcha2,t2",
    "firstevents": 1,
    "spid": "",
    "randid": randid,
    "m": 1,
    "lang": lang
  }

  try:
    res = session.post (config.OM_START_URL.format(str(port))+f"?caps={payload['caps']}&firstevents={payload['firstevents']}&spid=&randid={payload['randid']}&m=1&lang={payload['lang']}", payload)
    return json.loads(res.text)
  except Exception as e:
    return e
